#!/bin/bash
#
# Written by Tobias Lensing, http://tlensing.org
# For more information see http://blog.tlensing.org/2013/02/24/objective-c-on-linux-setting-up-gnustep-clang-llvm-objective-c-2-0-blocks-runtime-gcd-on-ubuntu-12-04/
#

die () {
    echo >&2 "$@"
    exit 1
}

getDirname () {
  if [[ $1 == *.tar.gz ]]; then
    echo "${1%.tar.gz}"
  elif [[ $1 == *.tgz ]]; then
    echo "${1%.tgz}"
  fi
}

PKG_OK=$(dpkg-query -W --showformat='${Status}\n' curl | grep "install ok installed")
echo "Checking for curl: $PKG_OK"
if [ "" == "$PKG_OK" ]; then
  sudo apt-get install curl -y
fi

echo Downloading libobjc2
tarobjc=libobjc2-1.7.tgz
[ ! -e $tarobjc ] && curl -O http://download.gna.org/gnustep/$tarobjc

echo Downloading GNUstep Make
targnustepmake=gnustep-make-2.6.6.tar.gz
[ ! -e $targnustepmake ] && curl -O ftp://ftp.gnustep.org/pub/gnustep/core/$targnustepmake

echo Downloading GNUstep Base
targnustepbase=gnustep-base-1.24.6.tar.gz
[ ! -e $targnustepbase ] && curl -O ftp://ftp.gnustep.org/pub/gnustep/core/$targnustepbase

echo Downloading GNUstep GUI
targnustepgui=gnustep-gui-0.24.0.tar.gz
[ ! -e $targnustepgui ] && curl -O ftp://ftp.gnustep.org/pub/gnustep/core/$targnustepgui

echo Downloading GNUstep Backend
targnustepback=gnustep-back-0.24.0.tar.gz
[ ! -e $targnustepback ] && curl -O ftp://ftp.gnustep.org/pub/gnustep/core/$targnustepback

PKG_OK=$(dpkg-query -W --showformat='${Status}\n' libdispatch-dev | grep "install ok installed")
echo "Checking for libdispatch-dev: $PKG_OK"
if [ "" != "$PKG_OK" ]; then
	sudo apt-get remove libdispatch-dev -y
fi

set -e

echo Installing required packages
#gobjc
sudo apt-get install build-essential clang libblocksruntime-dev libkqueue-dev libpthread-workqueue-dev libxml2-dev libjpeg-dev libtiff-dev libpng12-dev libcups2-dev libfreetype6-dev libcairo2-dev libxt-dev libgl1-mesa-dev libxslt1-dev libicu-dev cmake


echo Unpacking archives
dirobjc=`getDirname $tarobjc`
if [ ! -d $dirobjc ]; then
  tar xvfz $tarobjc
  [ $? -eq 0 ] || die "error unpacking $tarobjc"
fi

dirgnustepmake=`getDirname $targnustepmake`
if [ ! -d $dirgnustepmake ]; then
  tar xvfz $targnustepmake
  [ $? -eq 0 ] || die "error unpacking $targnustepmake"
fi

dirgnustepbase=`getDirname $targnustepbase`
if [ ! -d $dirgnustepbase ]; then
  tar xvfz $targnustepbase
  [ $? -eq 0 ] || die "error unpacking $targnustepbase"
fi

dirgnustepgui=`getDirname $targnustepgui`
if [ ! -d $dirgnustepgui ]; then
  tar xvfz $targnustepgui
  [ $? -eq 0 ] || die "error unpacking $targnustepgui"
fi

dirgnustepback=`getDirname $targnustepback`
if [ ! -d $dirgnustepback ]; then
  tar xvfz $targnustepback
  [ $? -eq 0 ] || die "error unpacking $targnustepback"
fi


echo Installing libobjc2
export CC=clang
cd $dirobjc
#make clean
#make
#sudo make install
make clean
cmake . -DCMAKE_C_COMPILER=clang -DCMAKE_CXX_COMPILER=clang++
make && sudo -E make install


cd ../$dirgnustepmake
./configure
sudo make install

cd ../$dirgnustepbase
make clean
./configure
make
sudo make install

cd ../$dirgnustepgui
export LD_LIBRARY_PATH=/usr/local/lib
make clean
./configure
make
sudo make install

cd ../$dirgnustepback
make clean
./configure
make
sudo make install

sudo apt-get install libdispatch-dev

echo Installation script finished successfully

